@@ -6,8 +6,8 @@ from typing import Optional, List
 
 from pydantic import BaseModel, Field
 
+from flask_openapi3 import Info, Tag
 from flask_openapi3 import OpenAPI
-from flask_openapi3.models import Info, Tag
 from flask_openapi3.models.security import HTTPBearer, OAuth2, OAuthFlows, OAuthFlowImplicit
 
 info = Info(title='book API', version='1.0.0')
@@ -20,7 +20,7 @@ oauth2 = OAuth2(flows=OAuthFlows(
             "read:pets": "read your pets"
         }
     )))
-securitySchemes = {"jwt": jwt, "oauth2": oauth2}
+security_schemes = {"jwt": jwt, "oauth2": oauth2}
 
 
 class NotFoundResponse(BaseModel):
@@ -28,7 +28,7 @@ class NotFoundResponse(BaseModel):
     message: str = Field("Resource not found!", description="Exception Information")
 
 
-app = OpenAPI(__name__, info=info, securitySchemes=securitySchemes, responses={"404": NotFoundResponse})
+app = OpenAPI(__name__, info=info, security_schemes=security_schemes, responses={"404": NotFoundResponse})
 
 book_tag = Tag(name='book', description='Some Book')
 security = [
@@ -65,7 +65,15 @@ class BookResponse(BaseModel):
     data: Optional[BookBodyWithID]
 
 
-@app.get('/book/<int:bid>', tags=[book_tag], responses={"200": BookResponse}, security=security)
+@app.get(
+    '/book/<int:bid>',
+    tags=[book_tag],
+    summary='new summary',
+    description='new description',
+    responses={"200": BookResponse},
+    extra_responses={"200": {"content": {"text/csv": {"schema": {"type": "string"}}}}},
+    security=security
+)
 def get_book(path: BookPath):
     """Get book
     Get some book by id, like:
@@ -77,7 +85,7 @@ def get_book(path: BookPath):
 
 
 # set doc_ui False disable openapi UI
-@app.get('/book', doc_ui=True)
+@app.get('/book', doc_ui=True, deprecated=True)
 def get_books(query: BookQuery):
     """get books
     get all books
